{% load static %}

<script type="module" src='{% static 'admin/js/django_hstore_widget/django-hstore-widget.esm.js' %}'></script>


<django-hstore-widget style='width:100%' delete_svg_src='/static/admin/img/icon-deletelink.svg' add_svg_src='/static/admin/img/icon-addlink.svg' edit_svg_src='/static/admin/img/icon-changelink.svg' field_name="{{ field_name }}" json="{{ field_data }}" />
