import{p as e,b as o}from"./p-dbd792af.js";export{s as setNonce}from"./p-dbd792af.js";import{g as r}from"./p-e1255160.js";(()=>{const s=import.meta.url,o={};return""!==s&&(o.resourcesUrl=new URL(".",s).href),e(o)})().then((async s=>(await r(),o([["p-5000e2f0",[[0,"django-hstore-widget",{json:[513],field_name:[513],cols:[514],rows:[514],delete_svg_src:[1],add_svg_src:[1],edit_svg_src:[1],mounted:[32],error:[32],output_render_type:[32],__json:[32]},null,{json:["jsonWatcher"]}]]]],s))));